@@ -18,17 +18,21 @@
  *                                                                   
  * You should have received a copy of the GNU General Public License 
  * along with this program; if not, write to the Free Software       
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston,            
- * MA  02111-1307, USA.                                              
+ * Foundation, Inc., 51 Franklin Street, Boston,            
+ * MA  02110-1301, USA.                                              
  ****/
 
+#include "libxnee/xnee.h"
+#include "libxnee/print.h"
+#include "libxnee/print_varargs.h"
 
 #ifdef HAVE_STDARG_H
 #include <stdarg.h>
 #else
 #include <varargs.h> 
 #endif
-#include "libxnee/xnee.h"
+
+
 
 /**************************************************************
  *                                                            *
@@ -38,15 +42,20 @@
  **************************************************************/
 #ifdef HAVE_STDARG_H
 void
-xnee_verbosef (xnee_data *xd, char * msg, ...)
+xnee_verbosef (xnee_data *xd, /*@null@*/ char * msg,  ...)
 {
   
   va_list ap;
 
-  if (xd->verbose) 
+  if (xd==NULL)
+  {
+     return;
+  }
+
+  if (xd->verbose!=0) 
     {
       va_start(ap, msg);
-      xd->verbose_fp ( xd->err_file, msg, ap );
+      (void)xd->verbose_fp ( xd->err_file, msg, ap );
     }
 }
 
@@ -58,6 +67,11 @@ xnee_verbosef (xnee_data *xd, valist)
   char *fmt;
   va_list ap;
   
+  if (xd==NULL)
+  {
+     return;
+  }
+
   if (xd->verbose) 
     {
       va_start(argp);
@@ -79,7 +93,8 @@ xnee_print_error (char * error, ...)
 {
   va_list ap;
   va_start(ap, error);
-  vprintf ( error, ap );
+  (void)vprintf ( error, ap );
+  va_end(ap);
 }
 #else
 void
@@ -90,6 +105,7 @@ xnee_print_error (char * error, ...)
   va_start(ap);
   fmt = va_arg(argp, char *);
   vprintf ( error, ap );
+  va_end(ap);
 }
 #endif
 
